Dump version
=============

.. automodule:: drain_swamp.version_file.dump_version
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: Write semantic version to version file
   :ignore-module-all:
